import { getElement } from "@stencil/core";
/**
 * Call this function as soon as the click outside of annotated method's host is done.
 * @example
```
@ClickOutside()
callback() {
  // this will run when click outside of element (host component) is done.
}
```
 */
export function ClickOutside() {
    return (proto, methodName) => {
        const { render } = proto;
        proto.render = function () {
            const renderResult = render.call(this);
            const host = getElement(this);
            const method = this[methodName];
            registerClickOutside(host, method);
            return renderResult;
        };
    };
}
/**
 * Call this function as soon as the click outside of annotated method's host is done.
 * @example
```
@ClickOutside()
callback() {
  // this will run when click outside of element (host component) is done.
}
```
 */
export function registerClickOutside(element, callback) {
    window.addEventListener("click", (e) => {
        const target = e.target;
        if (!element.contains(target)) {
            callback.call(this);
        }
    }, false);
}
