"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@stencil/core");
/**
 * Call this function as soon as the click outside of annotated method's host is done.
 * @example
```
@ClickOutside()
callback() {
  // this will run when click outside of element (host component) is done.
}
```
 */
function ClickOutside() {
    return function (proto, methodName) {
        var render = proto.render;
        proto.render = function () {
            var renderResult = render.call(this);
            var host = core_1.getElement(this);
            var method = this[methodName];
            registerClickOutside(host, method);
            return renderResult;
        };
    };
}
exports.ClickOutside = ClickOutside;
/**
 * Call this function as soon as the click outside of annotated method's host is done.
 * @example
```
@ClickOutside()
callback() {
  // this will run when click outside of element (host component) is done.
}
```
 */
function registerClickOutside(element, callback) {
    var _this = this;
    window.addEventListener("click", function (e) {
        var target = e.target;
        if (!element.contains(target)) {
            callback.call(_this);
        }
    }, false);
}
exports.registerClickOutside = registerClickOutside;
